/*
 * Project name:
     Tilt click Board Example
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Revision History:
     20150325:
       - initial release (DM);
 * Description:
     This is a simple demonstration of the Tilt click Board usage.
 * Test configuration:
     MCU:             P32MX795F512L
                      http://ww1.microchip.com/downloads/en/DeviceDoc/61156F.pdf
     Dev.Board:       EasyPIC Fusion v7
                      http://www.mikroe.com/easypic-fusion/
     Oscillator:      XT-PLL, 80.000MHz
     ext. modules:    Tilt click board
                      http://www.mikroe.com/click/tilt/
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/mikroc/pic32/
 * NOTES:
     - Place Tilt click board at the mikroBUS socket 1 on the EasyPIC Fusion v7 board.
     - Put EasyTFT in its socket, turn on backlight using the SW11.1
 */

#include "resources.h"

// TFT module connections
char TFT_DataPort at LATE;
sbit TFT_RST at LATD7_bit;
sbit TFT_BLED at LATD2_bit;
sbit TFT_RS at LATD9_bit;
sbit TFT_CS at LATD10_bit;
sbit TFT_RD at LATD5_bit;
sbit TFT_WR at LATD4_bit;
char TFT_DataPort_Direction at TRISE;
sbit TFT_RST_Direction at TRISD7_bit;
sbit TFT_BLED_Direction at TRISD2_bit;
sbit TFT_RS_Direction at TRISD9_bit;
sbit TFT_CS_Direction at TRISD10_bit;
sbit TFT_RD_Direction at TRISD5_bit;
sbit TFT_WR_Direction at TRISD4_bit;
// End TFT module connections

sbit Tilt_V01 at RD0_bit;
sbit Tilt_V02 at RE8_bit;
sbit Tilt_V01_Direction at TRISD0_bit;
sbit Tilt_V02_Direction at TRISE8_bit;

void InitDisplay(){
  TFT_Init_ILI9341_8bit(320, 240);
  TFT_BLED = 1;
  TFT_Set_Pen(CL_WHITE, 1);
  TFT_Set_Brush(1,CL_WHITE,0,0,0,0);
  TFT_Set_Font(TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
  TFT_Fill_Screen(CL_WHITE);
  TFT_Set_Pen(CL_Black, 1);
  TFT_Line(20, 220, 300, 220);
  TFT_LIne(20,  46, 300,  46);
  TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("Tilt Click", 125, 14);
  TFT_Set_Font(&Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("EasyPIC Fusion v7", 19, 223);
  TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("www.mikroe.com", 200, 223);
  TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
  TFT_Image_Jpeg(80, 55, arrows_default_jpg);             // Print arrows_default jpg picture on display
}

void main() {
  Tilt_V01_Direction = 1;                                 // Set RD0 pin input
  Tilt_V02_Direction = 1;                                 // Set RE8 pin input

  InitDisplay();                                          // Display initialization
  
  while(1){
    if ((Tilt_V02 == 1) & (Tilt_V01 == 0)){
      TFT_Image_Jpeg(80, 55, arrows_left_jpg);            // Print arrows_left jpg picture on display
    }
    
    if ((Tilt_V02 == 0) & (Tilt_V01 == 1)){
      TFT_Image_Jpeg(80, 55, arrows_right_jpg);           // Print arrows_right jpg picture on display
    }
    
    if ((Tilt_V02 == 1) & (Tilt_V01 == 1)){
      TFT_Image_Jpeg(80, 55, arrows_up_jpg);              // Print arrows_up jpg picture on display
    }
    
    if ((Tilt_V02 == 0) & (Tilt_V01 == 0)){
      TFT_Image_Jpeg(80, 55, arrows_down_jpg);            // Print arrows_down jpg picture on display
    }
  }
}